==> qtmultimedia-everywhere-src-5.10.1.tar.xz: qtmultimedia-everywhere-src-5.10.1/src/plugins/qnx/mediaplayer/mmrenderermediaplayerservice.h <==
/****************************************************************************
**
** Copyright (C) 2016 Research In Motion
** Contact: https://www.qt.io/licensing/
**
** This file is part of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/
#ifndef MMRENDERERMEDIAPLAYERSERVICE_H
#define MMRENDERERMEDIAPLAYERSERVICE_H

#include <qmediaservice.h>
#include <QtCore/qpointer.h>

QT_BEGIN_NAMESPACE

class MmRendererAudioRoleControl;
class MmRendererMediaPlayerControl;
class MmRendererMetaDataReaderControl;
class MmRendererPlayerVideoRendererControl;
class MmRendererVideoWindowControl;

class MmRendererMediaPlayerService : public QMediaService
{
    Q_OBJECT
public:
    explicit MmRendererMediaPlayerService(QObject *parent = 0);
    ~MmRendererMediaPlayerService();

    QMediaControl *requestControl(const char *name) Q_DECL_OVERRIDE;
    void releaseControl(QMediaControl *control) Q_DECL_OVERRIDE;

private:
    void updateControls();

    QPointer<MmRendererPlayerVideoRendererControl> m_videoRendererControl;
    QPointer<MmRendererVideoWindowControl> m_videoWindowControl;
    QPointer<MmRendererMediaPlayerControl> m_mediaPlayerControl;
    QPointer<MmRendererMetaDataReaderControl> m_metaDataReaderControl;
    QPointer<MmRendererAudioRoleControl> m_audioRoleControl;

    bool m_appHasDrmPermission : 1;
    bool m_appHasDrmPermissionChecked : 1;
};

QT_END_NAMESPACE

#endif

==> qtmultimedia-everywhere-src-5.12.1.tar.xz: qtmultimedia-everywhere-src-5.12.1/src/plugins/qnx/mediaplayer/mmrenderermediaplayerservice.h <==
/****************************************************************************
**
** Copyright (C) 2016 Research In Motion
** Contact: https://www.qt.io/licensing/
**
** This file is part of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/
#ifndef MMRENDERERMEDIAPLAYERSERVICE_H
#define MMRENDERERMEDIAPLAYERSERVICE_H

#include <qmediaservice.h>
#include <QtCore/qpointer.h>

QT_BEGIN_NAMESPACE

class MmRendererAudioRoleControl;
class MmRendererCustomAudioRoleControl;
class MmRendererMediaPlayerControl;
class MmRendererMetaDataReaderControl;
class MmRendererPlayerVideoRendererControl;
class MmRendererVideoWindowControl;

class MmRendererMediaPlayerService : public QMediaService
{
    Q_OBJECT
public:
    explicit MmRendererMediaPlayerService(QObject *parent = 0);
    ~MmRendererMediaPlayerService();

    QMediaControl *requestControl(const char *name) override;
    void releaseControl(QMediaControl *control) override;

private:
    void updateControls();

    QPointer<MmRendererPlayerVideoRendererControl> m_videoRendererControl;
    QPointer<MmRendererVideoWindowControl> m_videoWindowControl;
    QPointer<MmRendererMediaPlayerControl> m_mediaPlayerControl;
    QPointer<MmRendererMetaDataReaderControl> m_metaDataReaderControl;
    QPointer<MmRendererAudioRoleControl> m_audioRoleControl;
    QPointer<MmRendererCustomAudioRoleControl> m_customAudioRoleControl;

    bool m_appHasDrmPermission : 1;
    bool m_appHasDrmPermissionChecked : 1;
};

QT_END_NAMESPACE

#endif
